@@ -13,10 +13,9 @@ test_that("Set of detected change points increases with decreasing epsilon", {
       cpts.prev.b <- numeric(0) # Include boundary extension
       G <- floor(runif(1, 5, 15))
       for (epsilon in (11:0)/10) { #TODO include 0
-        cpts.curr <- mosum(x, G,
-                                alpha=alpha, criterion="epsilon", epsilon=epsilon,
-                                boundary.extension=F)$cpts
-        cpts.curr.b <- mosum(x, G, boundary.extension=T,
+        cpts.curr <- mosum(x, G, boundary.extension=FALSE,
+                                alpha=alpha, criterion="epsilon", epsilon=epsilon)$cpts
+        cpts.curr.b <- mosum(x, G, boundary.extension=TRUE,
                                   alpha=alpha, criterion="epsilon", epsilon=epsilon)$cpts
         expect_true(all(cpts.prev %in% cpts.curr))
         expect_true(all(cpts.prev.b %in% cpts.curr.b))
@@ -26,6 +25,7 @@ test_that("Set of detected change points increases with decreasing epsilon", {
     }
   }
 })
+
 test_that("Set of detected change points increases with decreasing eta", {
   for (i in 1:N_TEST) {
     alpha <- runif(1, 0, 1)
@@ -39,9 +39,9 @@ test_that("Set of detected change points increases with decreasing eta", {
       cpts.prev.b <- numeric(0) # Include boundary extension
       G <- floor(runif(1, 5, 15))
       for (eta in (20:0)/10) {
-        cpts.curr <- mosum(x, G, boundary.extension=F,
+        cpts.curr <- mosum(x, G, boundary.extension=FALSE,
                                 alpha=alpha, criterion="eta", eta=eta)$cpts
-        cpts.curr.b <- mosum(x, G, boundary.extension=T,
+        cpts.curr.b <- mosum(x, G, boundary.extension=TRUE,
                                 alpha=alpha, criterion="eta", eta=eta)$cpts
         expect_true(all(cpts.prev %in% cpts.curr))
         expect_true(all(cpts.prev.b %in% cpts.curr.b))
